@@ -17,7 +17,7 @@ import traceback
 from pathlib import Path
 from typing import Generator, Dict
 
-from .config  import confservice
+from .config import confservice
 
 LOGGER = logging.getLogger('SRVLOG')
 
@@ -32,69 +32,76 @@ def checkQgisVersion(minver: str, maxver: str) -> bool:
         major, *ver = ver.split('.')
         major = int(major)
         minor = int(ver[0]) if len(ver) > 0 else 0
-        rev   = int(ver[1]) if len(ver) > 1 else 0
+        rev = int(ver[1]) if len(ver) > 1 else 0
         if minor >= 99:
             minor = rev = 0
             major += 1
         if rev > 99:
             rev = 99
-        return int("{:d}{:02d}{:02d}".format(major,minor,rev))
-
+        return int("{:d}{:02d}{:02d}".format(major, minor, rev))
 
     version = to_int(Qgis.QGIS_VERSION.split('-')[0])
-    minver  = to_int(minver) if minver else version
-    maxver  = to_int(maxver) if maxver else version
+    minver = to_int(minver) if minver else version
+    maxver = to_int(maxver) if maxver else version
 
     return minver <= version <= maxver
 
 
-
-def find_plugins(path: str) -> Generator[str,None,None]:
+def find_plugins(path: str) -> Generator[str, None, None]:
     """ return list of plugins in given path
     """
     path = Path(path)
     for plugin in path.glob("*"):
-        LOGGER.debug("Looking for plugin in %s", plugin)
+        LOGGER.debug(f"Looking for plugin in '{plugin}'")
+
         if not plugin.is_dir():
+            # Warn about dangling symlink
+            # This occurs when running in docker container
+            # and symlink target path are not visible from the
+            # container - give some hint for debugging
+            if plugin.is_symlink():
+                LOGGER.warning(f"*** The symbolic link '{plugin}' is not resolved."
+                               " If you are running in docker container please consider"
+                               "mounting the target path in the container.")
             continue
 
-        metadatafile = plugin / 'metadata.txt'
-        if not metadatafile.exists():
+        metadata_file = plugin / 'metadata.txt'
+        if not metadata_file.exists():
+            # Do not log here
             continue
 
         if not (plugin / '__init__.py').exists():
-            LOGGER.warning("Found metadata file but no entry point !")
+            LOGGER.warning(f"'{plugin}' : Found metadata file but no Python entry point !")
             continue
 
         cp = configparser.ConfigParser()
 
         try:
-            with metadatafile.open(mode='rt') as f:
+            with metadata_file.open(mode='rt') as f:
                 cp.read_file(f)
 
             if not cp['general'].getboolean('server'):
-                LOGGER.warning("%s is not a server plugin", plugin)
+                LOGGER.warning(f"'{plugin}' is not a server plugin")
                 continue
 
-            minver = cp['general'].get('qgisMinimumVersion')
-            maxver = cp['general'].get('qgisMaximumVersion')
+            min_ver = cp['general'].get('qgisMinimumVersion')
+            max_ver = cp['general'].get('qgisMaximumVersion')
 
         except Exception as exc:
-            LOGGER.error("Error reading plugin metadata '%s': %s",metadatafile,exc)
+            LOGGER.error(f"'{plugin}' : Error reading plugin metadata '{metadata_file}': {exc}")
             continue
 
-        if not checkQgisVersion(minver,maxver):
-            LOGGER.warning("Unsupported version for %s. Discarding", plugin)
+        if not checkQgisVersion(min_ver, max_ver):
+            LOGGER.warning(f"Unsupported version for {plugin}. Discarding")
             continue
 
         yield plugin.name
 
 
-
-def load_plugins(serverIface: 'QgsServerInterface'): # noqa F821
+def load_plugins(serverIface: 'QgsServerInterface'):  # noqa F821
     """ Start all plugins """
 
-    plugin_path = confservice.get('server','pluginpath')
+    plugin_path = confservice.get('server', 'pluginpath')
     if not plugin_path:
         return
 
@@ -125,7 +132,7 @@ def load_plugins(serverIface: 'QgsServerInterface'): # noqa F821
         LOGGER.warning(f"{error} plugin(s) having an issue")
 
 
-def plugin_metadata( plugin: str ) -> Dict:
+def plugin_metadata(plugin: str) -> Dict:
     """ Return plugin metadata
     """
     if plugin not in server_plugins:
@@ -140,8 +147,8 @@ def plugin_metadata( plugin: str ) -> Dict:
     with metadatafile.open(mode='rt') as f:
         cp = configparser.ConfigParser()
         cp.read_file(f)
-        metadata = { s: dict(p.items()) for s,p in cp.items() }
-        metadata.pop('DEFAULT',None)
+        metadata = {s: dict(p.items()) for s, p in cp.items()}
+        metadata.pop('DEFAULT', None)
         metadata.update(path=str(path))
         return metadata
 
