@@ -8,7 +8,7 @@
 
 """ Load balancer/proxy to morker processes
 
-    Implement ZMQ ROUTER/ROUTER broker for connecting client DEALER 
+    Implement ZMQ ROUTER/ROUTER broker for connecting client DEALER
     to workers DEALER
 """
 
@@ -25,10 +25,10 @@ from .messages import WORKER_READY
 
 from ..logger import setup_log_handler
 
-LOGGER=logging.getLogger('SRVLOG')
+LOGGER = logging.getLogger('SRVLOG')
 
 
-def run_broker( inaddr: str, outaddr: str, maxqueue: int=100, timeout: int=3000) -> None:
+def run_broker(inaddr: str, outaddr: str, maxqueue: int = 100, timeout: int = 3000) -> None:
     """ Create a ROUTER-ROUTER broker
 
         :param inaddr: frontend address to bind to
@@ -37,44 +37,44 @@ def run_broker( inaddr: str, outaddr: str, maxqueue: int=100, timeout: int=3000)
         If the max number of waiting request is reached: extra incoming requests will
     """
     # Convert timeout to seconds
-    timeout = timeout/1000.0
+    timeout = timeout / 1000.0
 
     context = zmq.Context.instance()
 
     LOGGER.info("Binding frontend to %s", inaddr)
     frontend = context.socket(zmq.ROUTER)
     frontend.setsockopt(zmq.LINGER, 500)
-    frontend.setsockopt(zmq.ROUTER_MANDATORY,1)
+    frontend.setsockopt(zmq.ROUTER_MANDATORY, 1)
     frontend.bind(inaddr)
 
     LOGGER.info("Binding backend to %s", outaddr)
     backend = context.socket(zmq.ROUTER)
     backend.setsockopt(zmq.LINGER, 500)
-    backend.setsockopt(zmq.ROUTER_MANDATORY,1)
+    backend.setsockopt(zmq.ROUTER_MANDATORY, 1)
     backend.bind(outaddr)
 
-    poller = zmq.Poller()    
+    poller = zmq.Poller()
 
     # Only poll for requests from backend until workers are available
-    poller.register(backend,  zmq.POLLIN)
+    poller.register(backend, zmq.POLLIN)
     poller.register(frontend, zmq.POLLIN)
-   
-    workers = set() # Workers available
-    waiting = deque() # Client waiting
+
+    workers = set()    # Workers available
+    waiting = deque()  # Client waiting
 
     LOGGER.info("Starting ZMQ broker loop")
 
     # Try to exit gracefully
-    def term_signal(signum,frames):
+    def term_signal(signum, frames):
         LOGGER.debug("Broker process caught signal: %s" % signum)
         raise SystemExit()
 
-    signal.signal(signal.SIGTERM,term_signal)
+    signal.signal(signal.SIGTERM, term_signal)
 
     try:
         while True:
             # Poll incoming requests
-            sockets = dict(poller.poll())    
+            sockets = dict(poller.poll())
 
             # Handle worker activity on the backends
             if backend in sockets:
@@ -94,7 +94,8 @@ def run_broker( inaddr: str, outaddr: str, maxqueue: int=100, timeout: int=3000)
                             LOGGER.debug("SND worker: %s -> client: %s : %s", worker_id, client_id, msgid)
                         except zmq.ZMQError as err:
                             # ZMQ Will raise error if no client_id connected
-                            LOGGER.error("SND worker: %s -> client: %s', %s ,errno %s", worker_id, client_id, err, err.errno)
+                            LOGGER.error("SND worker: %s -> client: %s', %s ,errno %s",
+                                         worker_id, client_id, err, err.errno)
                 except Exception:
                     LOGGER.error("%s", traceback.format_exc())
 
@@ -129,15 +130,17 @@ def run_broker( inaddr: str, outaddr: str, maxqueue: int=100, timeout: int=3000)
                         worker_id = workers.pop()
                         try:
                             backend.send_multipart([worker_id, client_id, msgid, data])
-                            LOGGER.debug("SND client: %s -> worker: %s : %s", client_id, worker_id, msgid)
-                            break # Handle next request
+                            LOGGER.debug("SND client: %s -> worker: %s : %s",
+                                         client_id, worker_id, msgid)
+                            break  # Handle next request
                         except zmq.ZMQError as err:
-                            LOGGER.info("SND client: %s -> worker: %s, %s, errno %s", client_id, worker_id, err, err.errno)
-                            if not workers: 
+                            LOGGER.info("SND client: %s -> worker: %s, %s, errno %s",
+                                        client_id, worker_id, err, err.errno)
+                            if not workers:
                                 # No more workers available
                                 # push back the request on the queue
                                 waiting.append((tm, client_id, msgid, data))
-                            
+
     except (KeyboardInterrupt, SystemExit):
         LOGGER.warning("Broker Terminated")
     except Exception:
@@ -147,15 +150,22 @@ def run_broker( inaddr: str, outaddr: str, maxqueue: int=100, timeout: int=3000)
         frontend.close()
         context.term()
 
+
 if __name__ == '__main__':
     import argparse
     parser = argparse.ArgumentParser(description='Test broker')
-    parser.add_argument('--iface', metavar="host", default="tcp://127.0.0.1", help="Interface to bind to")
-    parser.add_argument('--in'   , dest='inaddr' , metavar='address', default='{iface}:8880', help="frontend address")
-    parser.add_argument('--out'  , dest='outaddr', metavar='address', default='{iface}:8881', help="backend address")
-    parser.add_argument('--logging', choices=['debug', 'info', 'warning', 'error'], default='info', help="set log level")
-    parser.add_argument('--maxqueue', metavar='NUM', type=int, default=100, help="Max waiting queue")
-    parser.add_argument('--timeout' , metavar='NUM', type=int, default=3000, help="Set timeout in ms for waiting requests")
+    parser.add_argument('--iface', metavar="host", default="tcp://127.0.0.1",
+                        help="Interface to bind to")
+    parser.add_argument('--in', dest='inaddr', metavar='address', default='{iface}:8880',
+                        help="frontend address")
+    parser.add_argument('--out', dest='outaddr', metavar='address', default='{iface}:8881',
+                        help="backend address")
+    parser.add_argument('--logging', choices=['debug', 'info', 'warning', 'error'], default='info',
+                        help="set log level")
+    parser.add_argument('--maxqueue', metavar='NUM', type=int, default=100,
+                        help="Max waiting queue")
+    parser.add_argument('--timeout', metavar='NUM', type=int, default=3000,
+                        help="Set timeout in ms for waiting requests")
 
     args = parser.parse_args()
 
@@ -164,7 +174,7 @@ if __name__ == '__main__':
 
     LOGGER.setLevel(getattr(logging, args.logging.upper()))
 
-    run_broker(args.inaddr.format(iface=args.iface), 
+    run_broker(args.inaddr.format(iface=args.iface),
                args.outaddr.format(iface=args.iface),
                maxqueue=args.maxqueue,
                timeout=args.timeout)
