@@ -9,7 +9,7 @@
 """ Define Qgis Worker
 
     We define QGis workers as DEALER configuration: it will enables
-    us to forward streamed response as chunked transfer.  
+    us to forward streamed response as chunked transfer.
 
     1. Start qgis application
     2. Connect a REQ zmq socket to endpoint
@@ -31,9 +31,7 @@ from ..utils import stats
 from .messages import (WORKER_READY, ReplyMessage)
 from .supervisor import Client as SupervisorClient
 
-
-
-LOGGER=logging.getLogger('SRVLOG')
+LOGGER = logging.getLogger('SRVLOG')
 
 # Define an abstract type for HTTPRequest
 HTTPRequest = TypeVar('HTTPRequest')
@@ -42,9 +40,9 @@ HTTPRequest = TypeVar('HTTPRequest')
 class RequestHandler:
 
     def __init__(self, socket: zmq.Socket, client_id: bytes, correlation_id: bytes, request: HTTPRequest) -> None:
-        """ Handle requests and 
-        
-            Handle reply message contruction and pass message correlation_id to 
+        """ Handle requests and
+
+            Handle reply message contruction and pass message correlation_id to
             reply.
 
             :param request: An HTTP request handler
@@ -56,10 +54,10 @@ class RequestHandler:
         self.header_written = False
 
         self._correlation_id = correlation_id
-        self._socket    = socket
+        self._socket = socket
         self._client_id = client_id
 
-    def _write( self, data: bytes ) -> None:
+    def _write(self, data: bytes) -> None:
         """ Send data back to client
         """
         self._socket.send_multipart([
@@ -67,20 +65,20 @@ class RequestHandler:
             self._correlation_id,
             data])
 
-    def send( self, data: bytes, send_more: bool=False, meta: Any = None ) -> None:
+    def send(self, data: bytes, send_more: bool = False, meta: Any = None) -> None:
         """ Send data
         """
         if not self.header_written:
-            # We let the client know that there is more 
+            # We let the client know that there is more
             # data by setting the 206 code (partial response)
-            if send_more and self.status_code==200:
+            if send_more and self.status_code == 200:
                 self.status_code = 206
             # Create a Header Message
-            message = pickle.dumps(ReplyMessage(self.status_code, headers=self.headers, data=data, meta=meta),-1)
-            self._write( message ) 
+            message = pickle.dumps(ReplyMessage(self.status_code, headers=self.headers, data=data, meta=meta), -1)
+            self._write(message)
             self.header_written = True
         elif self.status_code == 206:
-            self._write(pickle.dumps((data, send_more, meta),-1))
+            self._write(pickle.dumps((data, send_more, meta), -1))
             if not send_more:
                 self.status_code = 200
 
@@ -110,22 +108,22 @@ class RequestHandler:
         return data
 
 
-def dealer_socket( ctx: zmq.Context, address: str, identity: Optional[bytes]=None ) -> zmq.Socket:
+def dealer_socket(ctx: zmq.Context, address: str, identity: Optional[bytes] = None) -> zmq.Socket:
     """ Socket for receiving incoming messages
     """
     LOGGER.debug("Connecting to %s", address)
     sock = ctx.socket(zmq.DEALER)
-    sock.setsockopt(zmq.LINGER, 500)    # Needed for socket no to wait on close
-    sock.setsockopt(zmq.SNDHWM, 1)      # Max 1 item on send queue
-    sock.setsockopt(zmq.IMMEDIATE, 1)   # Do not queue if no peer, will block on send
-    sock.setsockopt(zmq.RCVTIMEO, 1000) # Heartbeat
+    sock.setsockopt(zmq.LINGER, 500)     # Needed for socket no to wait on close
+    sock.setsockopt(zmq.SNDHWM, 1)       # Max 1 item on send queue
+    sock.setsockopt(zmq.IMMEDIATE, 1)    # Do not queue if no peer, will block on send
+    sock.setsockopt(zmq.RCVTIMEO, 1000)  # Heartbeat
     sock.identity = identity or uuid.uuid1().bytes
     LOGGER.debug("Identity set to %s", sock.identity)
     sock.connect(address)
     return sock
 
 
-def broadcast_socket( ctx: zmq.Context, broadcastaddr: str ) -> zmq.Socket:
+def broadcast_socket(ctx: zmq.Context, broadcastaddr: str) -> zmq.Socket:
     """ Socket for receiving broadcast message notifications
     """
     LOGGER.debug("Enabling broadcast notification")
@@ -138,16 +136,16 @@ def broadcast_socket( ctx: zmq.Context, broadcastaddr: str ) -> zmq.Socket:
     return sub
 
 
-def run_worker(address: str, handler_factory: Type[RequestHandler], 
-               identity: Optional[bytes]=None, broadcastaddr: Optional[str]=None,
-               postprocess=Callable[[],None]) -> None:
+def run_worker(address: str, handler_factory: Type[RequestHandler],
+               identity: Optional[bytes] = None, broadcastaddr: Optional[str] = None,
+               postprocess=Callable[[], None]) -> None:
     """ Enter the message loop
     """
     ctx = zmq.Context.instance()
 
-    sock = dealer_socket( ctx, address, identity )
+    sock = dealer_socket(ctx, address, identity)
     if broadcastaddr:
-        sub = broadcast_socket( ctx, broadcastaddr )
+        sub = broadcast_socket(ctx, broadcastaddr)
 
     # Initialize supervisor client
     supervisor = SupervisorClient()
@@ -175,7 +173,7 @@ def run_worker(address: str, handler_factory: Type[RequestHandler],
                 LOGGER.error("Worker Error %d: %s", err.errno, zmq.strerror(err.errno))
             except Exception as exc:
                 LOGGER.error("Worker Error %s", exc)
-                # Print trace outside LOGGER because 
+                # Print trace outside LOGGER because
                 # logging output in sub-processe
                 # is not captured by pytest
                 traceback.print_exc()
@@ -191,12 +189,12 @@ def run_worker(address: str, handler_factory: Type[RequestHandler],
             try:
                 if broadcastaddr:
                     msg = sub.recv(flags=zmq.NOBLOCK)
-                    if msg==b'RESTART':
+                    if msg == b'RESTART':
                         # There is no really way to restart
                         # so exit and let the framework restart a new worker
                         LOGGER.info("Exiting on RESTART notification")
                         break
-                    elif msg==b'REPORT':
+                    elif msg == b'REPORT':
                         # Reporting asked
                         supervisor.send_report(handler_factory.get_report())
             except zmq.error.Again:
@@ -221,9 +219,10 @@ def run_worker(address: str, handler_factory: Type[RequestHandler],
 if __name__ == '__main__':
     import argparse
     parser = argparse.ArgumentParser(description='Test worker')
-    parser.add_argument('--host'    , metavar="host"   , default='tcp://localhost', help="router host")   
-    parser.add_argument('--router'  , metavar='address', default='{host}:8881', help="router address")
-    parser.add_argument('--logging' , choices=['debug', 'info', 'warning', 'error'], default='info', help="set log level")
+    parser.add_argument('--host', metavar="host", default='tcp://localhost', help="router host")
+    parser.add_argument('--router', metavar='address', default='{host}:8881', help="router address")
+    parser.add_argument('--logging', choices=['debug', 'info', 'warning', 'error'], default='info',
+                        help="set log level")
     parser.add_argument('--identity', default="", help="Set worker identity")
 
     args = parser.parse_args()
@@ -233,7 +232,6 @@ if __name__ == '__main__':
 
     LOGGER.setLevel(getattr(logging, args.logging.upper()))
 
-    run_worker(args.router.format(host=args.host), RequestHandler, 
+    run_worker(args.router.format(host=args.host), RequestHandler,
                identity=bytes(args.identity.encode('ascii')))
     print("DONE", file=sys.stderr)
-
